-- +migrate Up notransaction

-- add cluster status for pending masters configuration upgrade
ALTER TYPE "cluster_status" ADD VALUE IF NOT EXISTS 'PENDING_UPGRADE_CLUSTER_CONFIGURATION';

-- add task type for masters configuration upgrade
ALTER TYPE "task_type" ADD VALUE IF NOT EXISTS 'UPGRADE_CLUSTER_CONFIGURATION';

CREATE TABLE "microversions" (
    "created_at" timestamp DEFAULT (now()),
    "deleted_at" timestamp,
    "microversion" serial PRIMARY KEY,
    "upgrade_nodes" boolean
);

CREATE TABLE "clusters_microversions" (
    "created_at" timestamp DEFAULT (now()),
    "updated_at" timestamp,
    "deleted_at" timestamp,
    "microversion" integer NOT NULL,
    "cluster_id" uuid NOT NULL,
    PRIMARY KEY ("microversion", "cluster_id")
);

ALTER TABLE "clusters_microversions" ADD FOREIGN KEY ("microversion") REFERENCES "microversions"("microversion");
ALTER TABLE "clusters_microversions" ADD FOREIGN KEY ("cluster_id") REFERENCES "clusters"("id");

CREATE INDEX ON "microversions" ("created_at");
CREATE INDEX ON "microversions" ("deleted_at");

CREATE INDEX ON "clusters_microversions" ("created_at");
CREATE INDEX ON "clusters_microversions" ("updated_at");
CREATE INDEX ON "clusters_microversions" ("deleted_at");

-- +migrate Down

-- no teardown for types because they might be in use

DROP TABLE "clusters_microversions";
DROP TABLE "microversions";
